﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using StrategicCombat.Shots;

namespace StrategicCombat.CombatUnits
{
    /// <summary>
    /// This class represent a flame thrower on the left side of the board.
    /// </summary>
    public class LeftFlameThrower : LeftCombatUnit
    {
        #region Constructors

        /// <summary>
        /// Create a new flamethrower that is positioned to the left on a board.
        /// </summary>
        /// <param name="content"></param>
        public LeftFlameThrower(ContentManager content, Vector2 position)
            : base(content, position)
        {
            // Load textures.
            this.boardUnitTexture = content.Load<Texture2D>("CombatUnits/LeftCombatUnits/LeftFlamethrower75");
            this.combatUnitTexture = content.Load<Texture2D>("CombatUnits/LeftCombatUnits/LeftFlamethrower50");
            this.shotTexture = content.Load<Texture2D>("Textures/Flame32");

            // Set movement restriction
            this.movementRestriction = new Vector2(2, 2);

            // Set the movement speed
            this.movementSpeed = 4;

            // Set the shot speed
            this.shotSpeed = 5f;
            this.healthDamage = 5;
            this.shotDelay = 5;
            this.shotDelayCounter = 0;

            // Set delay for movement sound.
            this.movementDelay = 20;
            this.movementDelayCounter = 0;

            // Set the health value.
            this.health = 480;

        }

        #endregion

        #region Methods

        /// <summary>
        /// Add a shot to the list of shots.
        /// </summary>
        public override void AddShot()
        {
            // Add a shot.
            this.shots.Add(new Shot(this.combatPosition + this.combatDirection * 41, this.combatDirection,
                0, new Point(32, 32), false, 5, false, false));
            this.shots.Add(new Shot(this.combatPosition + this.combatDirection * 54, this.combatDirection,
                0, new Point(32, 32), false, 5, false, false));
            this.shots.Add(new Shot(this.combatPosition + this.combatDirection * 67, this.combatDirection,
                0, new Point(32, 32), false, 5, false, false));
            this.shots.Add(new Shot(this.combatPosition + this.combatDirection * 80, this.combatDirection,
                0, new Point(32, 32), false, 5, false, false));

        } // End of the AddShot method.

        /// <summary>
        /// Play a movement sound.
        /// </summary>
        public override void PlayMovementSound()
        {
            Program.soundBank.PlayCue("soldierMovement");

        } // End of the PlayMovementSound method.

        /// <summary>
        /// Play a shooting sound.
        /// </summary>
        public override void PlayShootingSound()
        {
            Program.soundBank.PlayCue("flameThrowerShot");

        } // End of the PlayShootingSound method.

        #endregion

    } // End of class

} // End of namespace
