﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using StrategicCombat.Shots;

namespace StrategicCombat.CombatUnits
{
    /// <summary>
    /// This class represent a solidier placed on the left side of the board.
    /// </summary>
    public class LeftSoldier : LeftCombatUnit
    {
        #region Variables

        #endregion

        #region Constructors

        /// <summary>
        /// Create a new soldier that is positioned to the right on a board.
        /// </summary>
        /// <param name="content"></param>
        public LeftSoldier(ContentManager content, Vector2 position)
            : base(content, position)
        {
            // Load textures.
            this.boardUnitTexture = content.Load<Texture2D>("CombatUnits/LeftCombatUnits/LeftInfanterySoldier75");
            this.combatUnitTexture = content.Load<Texture2D>("CombatUnits/LeftCombatUnits/LeftInfanterySoldier50");
            this.shotTexture = content.Load<Texture2D>("Textures/whiteTile");

            // Set movement restriction
            this.movementRestriction = new Vector2(1,1);

            // Set the movement speed.
            this.movementSpeed = 2;

            // Set the shot speed
            this.shotSpeed = 8f;
            this.healthDamage = 20;
            this.shotDelay = 10;
            this.shotDelayCounter = 0;

            // Set delay for movement sound.
            this.movementDelay = 26;
            this.movementDelayCounter = 0;

            // Set the health value to 100.
            this.health = 360;

        }

        #endregion

        #region Methods

        /// <summary>
        /// Add a shot to the list of shots.
        /// </summary>
        public override void AddShot()
        {
            // Add a shot.
            this.shots.Add(new Shot(this.combatPosition + this.combatDirection * (this.frameSizeCombat.X / 2), this.combatDirection,
                this.shotSpeed, new Point(2, 2), true, 0, false, false));

        } // End of the AddShot method.

        /// <summary>
        /// Play a movement sound.
        /// </summary>
        public override void PlayMovementSound()
        {
            Program.soundBank.PlayCue("soldierMovement");

        } // End of the PlayMovementSound method.

        /// <summary>
        /// Play a shooting sound.
        /// </summary>
        public override void PlayShootingSound()
        {
            Program.soundBank.PlayCue("soldierShot");

        } // End of the PlayShootingSound method.

        #endregion

    } // End of class

} // End of namespace
