﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using StrategicCombat.Shots;

namespace StrategicCombat.CombatUnits
{
    /// <summary>
    /// This class represent a double shooter on the right side of the board.
    /// </summary>
    public class RightDoubleShooter : RightCombatUnit
    {
        #region Constructors

        /// <summary>
        /// Create a new double shooter that is positioned to the right on a board.
        /// </summary>
        /// <param name="content"></param>
        public RightDoubleShooter(ContentManager content, Vector2 position)
            : base(content, position)
        {
            // Load textures.
            this.boardUnitTexture = content.Load<Texture2D>("CombatUnits/RightCombatUnits/RightDoubleShooter75");
            this.combatUnitTexture = content.Load<Texture2D>("CombatUnits/RightCombatUnits/RightDoubleShooter50");
            this.shotTexture = content.Load<Texture2D>("Textures/DoubleBullet8");

            // Set movement restriction
            this.movementRestriction = new Vector2(2, 2);

            // Set the movement speed
            this.movementSpeed = 2;

            // Set the shot speed
            this.shotSpeed = 10f;
            this.healthDamage = 22;
            this.shotDelay = 15;
            this.shotDelayCounter = 0;

            // Set delay for movement sound.
            this.movementDelay = 26;
            this.movementDelayCounter = 0;

            // Set the health value to 100.
            this.health = 480;

        }

        #endregion

        #region Methods

        /// <summary>
        /// Add a shot to the list of shots.
        /// </summary>
        public override void AddShot()
        {
            // Add a shot.
            this.shots.Add(new Shot(this.combatPosition + Vector2.Transform(this.combatDirection, Matrix.CreateRotationZ(MathHelper.ToRadians(270))) * 20 + this.combatDirection * 28, this.combatDirection,
                this.shotSpeed, new Point(8, 8), true, 0, false, false));
            this.shots.Add(new Shot(this.combatPosition + Vector2.Transform(this.combatDirection, Matrix.CreateRotationZ(MathHelper.ToRadians(90))) * 20 + this.combatDirection * 28, this.combatDirection,
                this.shotSpeed, new Point(8, 8), true, 0, false, false));

        } // End of the AddShot method.

        /// <summary>
        /// Play a movement sound.
        /// </summary>
        public override void PlayMovementSound()
        {
            Program.soundBank.PlayCue("soldierMovement");

        } // End of the PlayMovementSound method.

        /// <summary>
        /// Play a shooting sound.
        /// </summary>
        public override void PlayShootingSound()
        {
            Program.soundBank.PlayCue("shooterPlaneShot");

        } // End of the PlayShootingSound method.

        #endregion

    } // End of class
}
