﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using StrategicCombat.Shots;

namespace StrategicCombat.CombatUnits
{
    /// <summary>
    /// This class represent a plane on the right side of the board.
    /// </summary>
    public class RightPlane : RightCombatUnit
    {
        #region Constructors

        /// <summary>
        /// Create a new plane that is positioned to the right on a board.
        /// </summary>
        /// <param name="content"></param>
        public RightPlane(ContentManager content, Vector2 position)
            : base(content, position)
        {
            // Load textures.
            this.boardUnitTexture = content.Load<Texture2D>("CombatUnits/RightCombatUnits/RightPlane75");
            this.combatUnitTexture = content.Load<Texture2D>("CombatUnits/RightCombatUnits/RightPlane50");
            this.shotTexture = content.Load<Texture2D>("Textures/Flame82");

            // Set movement restriction
            this.movementRestriction = new Vector2(3, 3);

            // Set the movement speed
            this.movementSpeed = 6;

            // Set the shot speed
            this.shotSpeed = 5f;
            this.healthDamage = 100;
            this.shotDelay = 180;
            this.shotDelayCounter = 0;

            // Set delay for movement sound.
            this.movementDelay = 9;
            this.movementDelayCounter = 0;

            // Set the health value to 100.
            this.health = 580;

        }

        #endregion

        #region Methods

        /// <summary>
        /// Add a shot to the list of shots.
        /// </summary>
        public override void AddShot()
        {
            // Add a shot.
            this.shots.Add(new Shot(this.combatPosition, this.combatDirection,
                0, new Point(82, 82), false, 20, false, false));

        } // End of the AddShot method.

        /// <summary>
        /// Play a movement sound.
        /// </summary>
        public override void PlayMovementSound()
        {
            Program.soundBank.PlayCue("planeMovement");

        } // End of the PlayMovementSound method.

        /// <summary>
        /// Play a shooting sound.
        /// </summary>
        public override void PlayShootingSound()
        {
            Program.soundBank.PlayCue("bomberPlaneShot");

        } // End of the PlayShootingSound method.

        #endregion

    } // End of class

} // End of namespace
