﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using StrategicCombat.Shots;

namespace StrategicCombat.CombatUnits
{
    /// <summary>
    /// This class represent a tank that is positioned on the right side of the board.
    /// </summary>
    public class RightTank : RightCombatUnit
    {

        #region Constructors

        /// <summary>
        /// Create a new tank that is positioned to the right on a board.
        /// </summary>
        /// <param name="content"></param>
        public RightTank(ContentManager content, Vector2 position)
            : base(content, position)
        {
            // Load textures.
            this.boardUnitTexture = content.Load<Texture2D>("CombatUnits/RightCombatUnits/RightTank75");
            this.combatUnitTexture = content.Load<Texture2D>("CombatUnits/RightCombatUnits/RightTank50");
            this.shotTexture = content.Load<Texture2D>("Textures/TankBullet16");

            // Set movement restriction
            this.movementRestriction = new Vector2(7, 1);

            // Set the movement speed
            this.movementSpeed = 1;

            // Set the shot speed
            this.shotSpeed = 10f;
            this.healthDamage = 150;
            this.shotDelay = 50;
            this.shotDelayCounter = 0;

            // Set delay for movement sound.
            this.movementDelay = 2;
            this.movementDelayCounter = 0;

            // Set the health value.
            this.health = 580;

        }

        #endregion

        #region Methods

        /// <summary>
        /// Add a shot to the list of shots.
        /// </summary>
        public override void AddShot()
        {
            // Add a shot.
            this.shots.Add(new Shot(this.combatPosition + this.combatDirection * (this.frameSizeCombat.X / 2), this.combatDirection,
                this.shotSpeed, new Point(16, 16), true, 0, false, false));

        } // End of the AddShot method.

        /// <summary>
        /// Play a movement sound.
        /// </summary>
        public override void PlayMovementSound()
        {
            Program.soundBank.PlayCue("tankMovement");

        } // End of the PlayMovementSound method.

        /// <summary>
        /// Play a shooting sound.
        /// </summary>
        public override void PlayShootingSound()
        {
            Program.soundBank.PlayCue("tankShot");

        } // End of the PlayShootingSound method.

        #endregion

    } // End of class

} // End of namespace
